dropped property

  1. @override
int get dropped
override

Hops that the consumer was too slow to collect.

monowave shows this count and does not hide it. A value that is more than zero means that some data did not reach the visualizer. If the bars stutter, this count is the first item to examine.

Implementation

@override
int get dropped => _dropped;