frames property
Reduced frames, in order.
This stream is a broadcast stream. Therefore, a visualizer and a meter can both listen to it.
Implementation
@override
Stream<CaptureFrame> get frames => _frames.stream;
Reduced frames, in order.
This stream is a broadcast stream. Therefore, a visualizer and a meter can both listen to it.
@override
Stream<CaptureFrame> get frames => _frames.stream;