stopResult property
What stop returns. The default is peaks from the frames that this fake emitted.
Implementation
WaveformPeaks? stopResult;
What stop returns. The default is peaks from the frames that this fake emitted.
WaveformPeaks? stopResult;