truncated property
Whether the history is more than CaptureConfig.maxDuration.
Past that limit, the peaks from stop are partial.
Implementation
@override
bool get truncated => false;
Whether the history is more than CaptureConfig.maxDuration.
Past that limit, the peaks from stop are partial.
@override
bool get truncated => false;