decodeBytes method

  1. @override
Future<WaveformPeaks> decodeBytes(
  1. Uint8List bytes, {
  2. int baseSamplesPerPixel = 128,
})
override

This method decodes a container that is already in memory. On web, this method is the only decode path.

Implementation

@override
Future<WaveformPeaks> decodeBytes(
  Uint8List bytes, {
  int baseSamplesPerPixel = 128,
}) async => _decode(bytes.length);