decodeFile method
This method decodes the audio file at path into a peak pyramid.
Web has no filesystem, so this method is not available there. On web, decodeBytes does this work instead. On native, this method is the better choice, because the decoder streams the file one bucket at a time. Therefore an audiobook never has to be resident in memory.
If the container cannot be read, this method throws MonowaveDecodeException.
Implementation
@override
Future<WaveformPeaks> decodeFile(
String path, {
int baseSamplesPerPixel = 128,
}) async => _decode(path);