decoded property

Map<Object, WaveformPeaks> decoded
final

The peaks that the decode methods return, keyed by path or by byte length. An input that is not in this map gets defaultPeaks.

Implementation

final Map<Object, WaveformPeaks> decoded = {};