defaultPeaks property

WaveformPeaks Function() defaultPeaks
getter/setter pair

If the input is not in decoded, the decode returns this value. The default is two seconds of silence at 44.1 kHz.

Implementation

WaveformPeaks Function() defaultPeaks = () =>
    WaveformPeaks.fromSamples(Int16List(88200), sampleRate: 44100);