nextRender property

Int16List? nextRender
getter/setter pair

What renderPcm returns. The default is silence with one frame for each source frame that the document describes. As a result, a host can assert on the length with no need to synthesize audio.

Implementation

Int16List? nextRender;