frames property
Reduced frames, in order. Broadcast, so a visualizer and a meter can both listen.
Implementation
@override
Stream<CaptureFrame> get frames => _frames.stream;
Reduced frames, in order. Broadcast, so a visualizer and a meter can both listen.
@override
Stream<CaptureFrame> get frames => _frames.stream;