decodeBytes method
This method decodes a container that is already in memory. On web, this method is the only decode path.
Implementation
@override
Future<WaveformPeaks> decodeBytes(
Uint8List bytes, {
int baseSamplesPerPixel = 128,
}) async => _decode(bytes.length);