decoded property
The peaks that the decode methods return, keyed by path or by byte length. An input that is not in this map gets defaultPeaks.
Implementation
final Map<Object, WaveformPeaks> decoded = {};
The peaks that the decode methods return, keyed by path or by byte length. An input that is not in this map gets defaultPeaks.
final Map<Object, WaveformPeaks> decoded = {};