initializeCount property
How many times a caller awaited ensureInitialized. This count shows a host that loads the C core on every build instead of one time only.
Implementation
int initializeCount = 0;
How many times a caller awaited ensureInitialized. This count shows a host that loads the C core on every build instead of one time only.
int initializeCount = 0;